@@ -1,7 +1,7 @@
 
 
 "getNe"<-function(Year, Div,df=3.5,I){
-	for(j in 2:length(Div)){if(Div[j]>Div[j-1])Div[j]<-Div[j-1]}
+	for(j in 2:length(Div)){if(is.na(Div[j]) || Div[j]>Div[j-1])Div[j]<-Div[j-1]}
 	DivEst <- c(predict(sm.spline(Year, Div, df=df), Year, 0))
 	DivAbl <- c(predict(sm.spline(Year, Div, df=df), Year, 1))
 	deltaf <- -I*DivAbl/DivEst
