@@ -1,6 +1,6 @@
 "read.indiv"<-function(file, skip=NA, cskip=NA){
-  if(is.na(skip)){  skip <- getskip(file)}
-  if(is.na(cskip)){cskip <- getcskip(file, skip)}
+  if(is.na(skip)){  skip <- getskip(file, quiet=TRUE)}
+  if(is.na(cskip)){cskip <- getcskip(file, skip, quiet=TRUE)}
   IndivFileC <- scan(file, nlines=1, what="character",quiet=TRUE, skip=skip)
   if(cskip>0){IndivFileC <-IndivFileC[-(1:cskip)]}
   if(length(IndivFileC)==0){return(character(0))}
